@@ -13,12 +13,13 @@ from ansurr import rigidipy
 from ansurr import compare
 from ansurr import cyrange
 from ansurr import plot2D
+from ansurr import dssp
 
 from ansurr.functions import check_quiet_print
 from datetime import datetime
 
 sys.tracebacklimit = 0
-version = "0.0.24"
+version = "0.0.26"
 
 natsort = lambda s: [int(t) if t.isdigit() else t.lower() for t in re.split('(\d+)', s)]
 
@@ -67,6 +68,9 @@ def main():
         check_quiet_print(args.quiet,' -> CRITICAL ERROR failed to extract any models, exiting')
         sys.exit(1)
 
+    for pdb in glob.glob(output_dir+'/other_output/extracted_pdbs/*.pdb'):
+        dssp.calc_secondary_structure(pdb,output_dir+'/other_output/dssp/',quiet=args.quiet)
+
     if args.welldef:
         cyrange.calc_welldefined(path_to_pdb,output_dir,args.quiet)
 
